@@ -17,11 +17,11 @@ print_size_histogram (tree_chunk_info *ch)
   for (int i = 0; i < ch->n_kinds; i++)
     {
       tree_kind k = ch->node_kinds[i];
-      if (k->size > max)
+      if (k->size > (size_t) max)
 	max = k->size;
-      if (k->size < min)
+      if (k->size < (size_t) min)
 	min = k->size;
-      if (k->size < N)
+      if (k->size < (size_t) N)
 	sizes[k->size]++;
       if (k->size % 4 !=0)
 	printf ("odd size: %d\n", k->size);
