@@ -109,7 +109,7 @@ L4ieee_Q18std_logic_unsigned_init_done=true;
 L3std_Q8standard_init ();
 L4ieee_Q15std_logic_arith_init ();
 L4ieee_Q14std_logic_1164_init ();
-register_source_file("/home/stefan/cvs/freehdl/ieee/std_logic_unsigned.vhdl","std_logic_unsigned.vhdl");
+register_source_file("/home/stefan/cvs-local/freehdl-teaser/ieee/std_logic_unsigned.vhdl","std_logic_unsigned.vhdl");
 name_stack iname;
 iname.push("");
 void *sref=register_package(":ieee",":std_logic_unsigned");
@@ -496,7 +496,7 @@ L4ieee_Q18std_logic_unsigned_init ();
 L3std_Q8standard_init ();
 L4ieee_Q15std_logic_arith_init ();
 L4ieee_Q14std_logic_1164_init ();
-register_source_file("/home/stefan/cvs/freehdl/ieee/std_logic_unsigned.vhdl","std_logic_unsigned.vhdl");
+register_source_file("/home/stefan/cvs-local/freehdl-teaser/ieee/std_logic_unsigned.vhdl","std_logic_unsigned.vhdl");
 name_stack iname;
 iname.push("");
 void *sref=register_package_body(":ieee",":std_logic_unsigned");
