@@ -1,4 +1,3 @@
-#define KERNEL
 #if HAVE_ALLOCA_H
 #include <alloca.h>
 #endif
@@ -12,11 +11,15 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <sys/types.h>
+#if HAVE_SOCKET
+#include <sys/socket.h>
+#endif
 
 extern "C" {
 #include <regex.h>
 }
 
+#define KERNEL
 #include <freehdl/kernel-acl.hh>
 #include <freehdl/kernel-flags.hh>
 #include <freehdl/kernel-kernel-class.hh>
@@ -1132,7 +1135,7 @@ int
 kernel_main (int argc, char *argv[], handle_info *hinfo) {
 
   // Savely initialize the 'free_acl' memory
-  memset (free_acl, sizeof(acl*)*(MAX_ACL_DEPTH+1), 0); 
+  memset (free_acl, 0, sizeof(acl*)*(MAX_ACL_DEPTH+1)); 
 
   // Store command line arguments
   main_argc = argc;
