@@ -2058,7 +2058,7 @@ array_info::read(void *dest, const char *str)
  *  Record info class
  * ************************************************************* */
 
-record_info::record_info(int rs, int ds, char **en,void *(*ea)(void*, int), int rc) :
+record_info::record_info(int rs, int ds, const char **en,void *(*ea)(void*, int), int rc) :
   type_info_interface(RECORD, record_base::size())
 {
   set(rs, ds, en, ea, rc);
