@@ -29,7 +29,7 @@ string sprint_acl(list<string> &acl_list, const string acl_object);
 string
 cdfg_get_subprogram_identifier_string(pIIR_SubprogramDeclaration sd)
 {
-  char *separator = "";
+  const char *separator = "";
   string result = "\"" + get_escaped_string(get_long_name(sd))+ "(";
   for (pIIR_InterfaceList al = sd->interface_declarations; al; al = al->rest) {
     result += separator + get_escaped_string(get_long_name(get_declaration(al->first->subtype)));
