@@ -5,6 +5,7 @@
 #include <malloc.h>
 #endif
 #include <math.h>
+#include <limits.h>
 
 #include "v2cc-util.h"
 
@@ -107,7 +108,7 @@ calculate_pow(double a, lint b)
 }
 
 
-char *
+const char *
 ppp(pIIR_Root n)
 {
   return n->kind_name();
@@ -188,7 +189,7 @@ get_library_and_unit_name(pIIR_Declaration decl)
 
 
 /* Get source file name associated with a node */
-char *
+const char *
 get_source_file_name(pIIR_Root n)
 {
   if (n->pos->is(IR_POS_INFO_TEXT_FILE))
