@@ -495,6 +495,12 @@ mypool::get (char *l, char *n)
       vaul_parser_options opts = parser_options;
       opts.set_skip_bodies (true);
       vaul_design_file df(fn, NULL, opts);
+      // Skip "no such file" errors without verbosity set.
+      if (df.is_error ()) {
+	if (codegen_options.get_verbose ())
+	  df.print_err (fn);
+	df.clear_error();
+      }
 
       begin_session (l);
       while (vaul_design_unit * du = df.read_design_unit (this))
@@ -805,8 +811,10 @@ emit (vaul_pool *pool, char *file, string &str, string &cdfg_str, string &main_c
 	    string code;
 	    if (codegen_options.get_emit_debug_code ())
 	      code = "#line 1000000 __FILE__\n";
-	
-	    emit_decl (lu, code, rstack, 0);
+	    
+	    //if (lu->declarations != NULL)
+	      emit_decl (lu, code, rstack, 0);
+	    
 	    str += code;
 	  }
 
@@ -884,7 +892,7 @@ get_library_unit(pIIR_DeclarativeRegion d)
   return (pIIR_LibraryUnit)d;
 }
 
-// returns name of the libraray
+// returns name of the library
 char *
 get_lib_name(pIIR_DeclarativeRegion r)
 {
