@@ -237,7 +237,7 @@ max (const lint a, const lint b)
 inline bool
 and_reduce (const vector < bool > &vec)
 {
-  for (int i = 0; i < vec.size (); i++)
+  for (unsigned int i = 0; i < vec.size (); i++)
     if (!vec[i])
       return false;
 
@@ -247,7 +247,7 @@ and_reduce (const vector < bool > &vec)
 inline bool
 or_reduce (const vector < bool > &vec)
 {
-  for (int i = 0; i < vec.size (); i++)
+  for (unsigned int i = 0; i < vec.size (); i++)
     if (vec[i])
       return true;
 
@@ -261,6 +261,7 @@ typedef list < pair < pIIR_Declaration, bool > > decl_flag_list;
 
 // Virtual base class for static values
 struct StaticDataBase {
+  virtual ~StaticDataBase() {};
   virtual lint &long_value () { assert (false); };
   virtual double &double_value () { assert (false); };
   virtual vector<int> &array_literal_value () { assert (false); };
@@ -659,19 +660,20 @@ struct StaticRangeDescriptor
     fill (valid.begin (), valid.end (), true);
   };
   StaticRangeDescriptor (const T l, const R d, const T r) :
-    left (l), dir (d), right (r) 
+    left (l), right (r), dir (d)
   {
     valid.resize (3);
     fill (valid.begin (), valid.end (), true);
   };
   StaticRangeDescriptor (const StaticRangeDescriptor &a) :
-    left (a.left), dir (a.dir), right (a.right), valid (a.valid) {};
+    left (a.left), right (a.right), dir (a.dir), valid (a.valid) {};
   StaticRangeDescriptor &operator = (const StaticRangeDescriptor &a) 
   {
     left = a.left;
     dir = a.dir;
     right = a.right;
     valid = a.valid;
+    return *this;
   };
   bool operator == (const StaticRangeDescriptor &a)  const
   {
