@@ -479,7 +479,7 @@ psr::bind_attrspec (pVAUL_AttributeSpec s)
   if (el->is(VAUL_ENTITY_NAME_LIST_IDS)) 
     {
       IR_Kind eclass = s->entities->entity_class;
-      char *ename = tree_kind_name (eclass);
+      const char *ename = tree_kind_name (eclass);
       
       for (pVAUL_DesigList il = pVAUL_EntityNameList_Ids(el)->ids;
 	   il; il = il->link)
