@@ -36,19 +36,19 @@
 #define psr vaul_parser
 
 pIIR_Identifier
-psr::make_id (char *id)
+psr::make_id (const char *id)
 {
   return mIIR_Identifier (int(0), (IR_Character *)id, strlen (id));
 }
 
 pIIR_StringLiteral
-psr::make_strlit (char *str)
+psr::make_strlit (const char *str)
 {
   return mIIR_StringLiteral (int(0), (IR_Character *)str, strlen (str));
 }
 
 pIIR_StringLiteral
-psr::make_opid (char *op)
+psr::make_opid (const char *op)
 {
   char *opidstr = vaul_aprintf ("\"%s\"", op);
   pIIR_StringLiteral l = make_strlit (opidstr);
@@ -995,7 +995,7 @@ vaul_decl_set::retain_lowcost ()
   return lc == INT_MAX ? -1 : lc;
 }
 
-static char *item_state[] = {
+static const char *item_state[] = {
   "invalid",
   "pot. invalid",
   "pot. valid",
@@ -1330,7 +1330,7 @@ psr::unselect_scope()
 }
 
 pIIR_Declaration
-psr::find_single_decl (pVAUL_Name name, IR_Kind exp_k, char *kind_name)
+psr::find_single_decl (pVAUL_Name name, IR_Kind exp_k, const char *kind_name)
 {
   vaul_decl_set ds(this);
   find_decls (ds, name);
