@@ -732,7 +732,11 @@ psr::build_CaseStat (pIIR_PosInfo pos, pIIR_Expression swex,
       return NULL;
     }
 
-  if (swex->subtype->declaration == NULL)
+  // Get "very" base type of the subtype
+  pIIR_Type baseType = swex->subtype;
+  while (baseType->base != NULL && baseType->base != baseType) baseType = baseType->base;
+  //if (swex->subtype->declaration == NULL)
+  if (baseType->declaration == NULL)
     {
       swex_type = get_type(mVAUL_SimpleName(pos, make_id("integer")));
       //pVAUL_SelName sn = mVAUL_SelName(pos, mVAUL_SimpleName(pos, make_id("std")),
