@@ -1250,7 +1250,7 @@ psr::add_File (pIIR_Identifier id,
     }
   if (name_and_mode && name_and_mode->mode != IR_UNKNOWN_MODE)
     {
-      char *mode_id;
+      const char *mode_id;
 
       if (mode != NULL)
 	{
