@@ -24,7 +24,7 @@
 
 #include <freehdl/vaul-util.h>
 
-char *vaul_application_name = "libvaul";
+const char *vaul_application_name = "libvaul";
 
 void
 vaul_vfatal (const char *fmt, va_list ap)
